#!/usr/bin/env python

import sys                  # access to command-line args
import string               # string functions
import opusutil             # utilites like PrintMsg

# python modules for this application
import os
import getopt

# local modules for this application
import archdbquery

#--------------------------------------------------------------------------
def DADSname_usage():
  opusutil.PrintMsg('F','Interactive Usage: DADSname inputFilename')
  return

#--------------------------------------------------------------------------
#
# Name: DADSname
#
# Description: Writes a translated filename on stdout, where any 
#              "long extension" found in the input filename is converted
#              to a "short extension", as dictated in the ARCH_DB 
#              ingest_long_ext table.
#
# Inputs: global sys.argv (command line arguments)
#         envvars:          
#           ARCH_SERVER - archive database server
#           ARCH_DB - name of archive database
#
#        Will EXIT (status=1) if incorrect command line arguments
#        are found.  This is a FATAL error.
#
# History:
#   date    opr     who     reason
# -------- -----  --------  --------------------------------------
# 07/03/08 60170  MSwam     first version
#
#--------------------------------------------------------------------------
def DADSname():
  #
  # parse command line arguments
  try:
    opts, args = getopt.getopt(sys.argv[1:], "h", ["help"])
  except getopt.GetoptError:
    # print help information and exit:
    DADSname_usage()
    sys.exit(1)

  # parse options
  for flag, value in opts:
    if flag in ("-h", "--help"):
      DADSname_usage()
      sys.exit(1)

  # verify required args
  if len(args) != 1:
    DADSname_usage()
    sys.exit(1)
  else: 
    inputFilename = args[0]

  # parse the file extension from the inputFilename
  # (assume HST OTFR dataset names only for now, which are of the form
  #  ipppssoot_EXT.fits, where EXT can have any chars, incl. underscores)
  #
  # start at the 1st underscore, stop before the next dot
  #
  basename = os.path.basename(inputFilename)
  startPos = basename.find("_")
  endPos   = basename.find(".")
  inputExt = basename[startPos+1:endPos]
  opusutil.PrintMsg("D","basename,ext:"+basename+", "+inputExt)

  # connect to the ARCH_DB
  arch_db = archdbquery.Arch_db(os.environ['ARCH_SERVER'], 
                                os.environ['ARCH_DB'])

  # given the mission and long extension value, retrieve the short extension
  # value from the ILE DB table
  #
  mission = "HST" # hard-coded for now
  shortExt = arch_db.ile_file_extension(mission, inputExt)
  opusutil.PrintMsg("D","shortExt:"+str(shortExt))

  if len(shortExt) == 0:
     # no short extension translation found, just return the inputFilename
     outputFilename = inputFilename
  else:
     # the short extension comes back in CAPS as the 1st element in a 
     # list of lists, convert to lowercase and form the output filename
     # by substituting the short extension for the original long extension
     #
     outputFilename = inputFilename.replace(inputExt, shortExt[0][0].lower())

  # close the database connection
  arch_db.close()

  # write the resulting name to stdout
  print outputFilename
  return

#-------------------------------------------------------------------------
# The main routine. 
#
# History:
# -------- -----  --------  --------------------------------------
# 07/03/08 60170  MSwam     first version
#
#-------------------------------------------------------------------------
#
DADSname()
sys.exit(0)

